package org.openxma.dsl.reference.dtoassembler.dao;

import org.openxma.dsl.platform.dao.*;
import org.openxma.dsl.reference.dtoassembler.dao.ChildDao;
import org.openxma.dsl.reference.dtoassembler.model.Child;
import org.openxma.dsl.reference.dtoassembler.model.Parent;

/**
 * Represents a Data Access Object, as defined in the
 * Core J2EE Pattern Catalog (see http://java.sun.com/blueprints/corej2eepatterns/Patterns/DataAccessObject.html),
 * to abstract and encapsulate all access to entity ChildDao.
 * @see ChildDao
 */
public interface ChildDaoGen extends GenericDao<Child,String>, EntityFactory<Child> {
    /**
     * Factory method to create an empty <code>Child</code> entity with an already assigned identifier.
     * The advantage of this approach, coupled with the fact that we're using the id for equals,
     * is that equality test's are immediately possible and therefore independent from the persistence state
     * of the entity. This in contrast to other solutions where auto generated Keys are used
     * which must wait until the object is persisted or differentiate between transient and managed states.
     * @return a new (transient), empty <code>Child</code> entity with an already assigned identifier.
     */
    Child create();
    /**
     * Factory method to create an empty <code>Child</code> taking all not null attributes.
     *
	 * @param parent
     * @return a new (transient ) <code>Child</code> entity with the given natural identifier and not null attributes set.
     */
    Child create(Parent parent);
    /**
     * Factory method to create and save an empty <code>Child</code> taking all not null attributes.
     *
	 * @param parent
     * @return a new (transient) <code>Child</code> entity with the given natural identifier and not null attributes set.
     */
    Child createAndSave(Parent parent);
}
