package org.openxma.dsl.reference.ui.layouting.client;

import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Shell;
import at.spardat.xma.component.EmbeddableComponent;
import at.spardat.xma.session.XMASessionClient;

/**
 * This class implements the generic client part of Layouting.
 * It provides the mapping between typeIds and classnames
 * of all pages in the component.
 *
 */
abstract public class LayoutingGen extends EmbeddableComponent implements ILayouting {

    /**
     * Initializes the LayoutingGen. This method is called
     * by the XMA-Runtime.
     *
     * @param session the XMASession, this LayoutingGen belongs to.
     */
    public LayoutingGen (XMASessionClient session) {
        super (session, false);
    }

    /** the unique typeId for the page LayoutingPage */
    public static final short LayoutingPageClass = 0;
    /** the unique typeId for the page AbsoluteAttachment */
    public static final short AbsoluteAttachmentClass = 1;
    /** the unique typeId for the page RelativeAttachment */
    public static final short RelativeAttachmentClass = 2;
    /** the unique typeId for the page TabulatorAttachment */
    public static final short TabulatorAttachmentClass = 3;
    /** the unique typeId for the page AbsoluteCharAttachment */
    public static final short AbsoluteCharAttachmentClass = 4;
    /** the unique typeId for the page SiblingAttachment */
    public static final short SiblingAttachmentClass = 5;
    /** the unique typeId for the page FieldParts */
    public static final short FieldPartsClass = 6;

    /**
    * Array of the classnames of all pages in
    * this component. The typeIds are used as indices
    * into this array.
     */
    static final String[] modelClasses = {
        "LayoutingPage",
        "AbsoluteAttachment",
        "RelativeAttachment",
        "TabulatorAttachment",
        "AbsoluteCharAttachment",
        "SiblingAttachment",
        "FieldParts"
    };

    /**
    * Gets the short classname for the given typeId of
    * a page in this component. The short classname does
    * not contain the package.
    *
    * @param typeId the unique typeId
    * @return the short classname
     */
    static public String getShortModelClass(short typeId) {
        return modelClasses[typeId];
    }

    /**
    * Gets the full classname for the given typeId of
    * a page in this component.
    *
    * @param typeId the unique typeId
    * @return the full classname
     */
    public String getModelClass(short typeId) {
        return "org.openxma.dsl.reference.ui.layouting.client."+modelClasses[typeId];
    }

    /**
     * Invokes the Layouting. This method is a default
     * implementation, which invokes the first dialog page of the component.
     * Modeled init functions are called by this method.
     *
     * @param parentComposite a composite of the calling page. In most
     *     cases it will be a shell. It my be null.
     */
    public void invoke(Composite parentComposite) {
        LayoutingPage layoutingPage_generatedXMAPage;
        if(parentComposite instanceof Shell) {
            layoutingPage_generatedXMAPage = new LayoutingPage(this,(Shell)parentComposite);
        } else {
            layoutingPage_generatedXMAPage = new LayoutingPage(this);
        }
        layoutingPage_generatedXMAPage.invoke();
    }

    /**
     * Gives the URI of the help for this component
     * This URI is relative to the download-URI of the component
     * @return the relative URI of the help for this component
     */
    public String getHelpUri() {
        return "help/org/openxma/dsl/reference/ui/layouting/Layouting.html";
    }

}
